@@ -1,7 +1,7 @@
 #ifndef AVIFILE_VERSION
 #define AVIFILE_MAJOR_VERSION 0
 #define AVIFILE_MINOR_VERSION 7
-#define AVIFILE_PATCHLEVEL 43
+#define AVIFILE_PATCHLEVEL 45
 #define AVIFILE_VERSION  ((AVIFILE_MAJOR_VERSION << 16) + (AVIFILE_MINOR_VERSION << 8) + AVIFILE_PATCHLEVEL)
-#define AVIFILE_BUILD "CVS-0.7.43-050224-14:40-(Debian"
+#define AVIFILE_BUILD "CVS-0.7.45-060306-10:11-4.0.3"
 #endif
