@@ -18,7 +18,7 @@
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: v4lxif.cpp,v 1.30 2004/11/04 13:43:50 kabi Exp $ */
+/* $Id: v4lxif.cpp,v 1.31 2005/03/23 16:16:09 kabi Exp $ */
 
 #include "v4lxif.h"
 
@@ -1115,10 +1115,10 @@ v4l1if::v4l1if(const char* mem, const char * _device, int _bpp, int _palette)
 		     major,minor, XDGA_MAJOR_VERSION,XDGA_MINOR_VERSION);
 		have_dga= false;
 	    } else {
-		XF86DGAGetVideoLL(disp, DefaultScreen(disp), (int *)&base, &width, &bank, &ram );
+		XF86DGAGetVideoLL(disp, DefaultScreen(disp), (int*)&base, &width, &bank, &ram);
 		if (!base)
 		    avml(AVML_WARN,
-			 "v4l1: can not allocate frame buffer base: 0x%x\n",(int)base);
+			 "v4l1: can not allocate frame buffer base: %p\n", base);
 	    }
 	}
     }
